@@ -1,4 +1,4 @@
-use poem::{handler, route, web::Path, RouteMethod, Server};
+use poem::{handler, route, route::get, web::Path, Server};
 
 #[handler]
 fn hello(Path(name): Path<String>) -> String {
@@ -7,7 +7,7 @@ fn hello(Path(name): Path<String>) -> String {
 
 #[tokio::main]
 async fn main() {
-    let app = route().at("/hello/:name", RouteMethod::new().get(hello));
+    let app = route().at("/hello/:name", get(hello));
     let server = Server::bind("127.0.0.1:3000").await.unwrap();
     server.run(app).await.unwrap();
 }
